Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: extensions/browser/content_verifier.h

Issue 2845223003: [Merge m59] Only whitelist messages.json files in _locales for content verification (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « extensions/browser/content_hash_fetcher.cc ('k') | extensions/browser/content_verifier.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: extensions/browser/content_verifier.h
diff --git a/extensions/browser/content_verifier.h b/extensions/browser/content_verifier.h
index 6d31f692b8429ffaf402ec5da79176b2068f2929..1dac391b3db905a4bf5c773dbe7e7df1efc7cde7 100644
--- a/extensions/browser/content_verifier.h
+++ b/extensions/browser/content_verifier.h
@@ -80,21 +80,23 @@ class ContentVerifier : public base::RefCountedThreadSafe<ContentVerifier>,
friend class base::RefCountedThreadSafe<ContentVerifier>;
~ContentVerifier() override;
- void OnFetchComplete(const std::string& extension_id,
- bool success,
- bool was_force_check,
- const std::set<base::FilePath>& hash_mismatch_paths);
+ void OnFetchComplete(
+ const std::string& extension_id,
+ bool success,
+ bool was_force_check,
+ const std::set<base::FilePath>& hash_mismatch_unix_paths);
void OnFetchCompleteHelper(const std::string& extension_id,
bool shouldVerifyAnyPathsResult);
- // Returns true if any of the paths in |relative_paths| *should* have their
- // contents verified. (Some files get transcoded during the install process,
- // so we don't want to verify their contents because they are expected not
- // to match).
- bool ShouldVerifyAnyPaths(const std::string& extension_id,
- const base::FilePath& extension_root,
- const std::set<base::FilePath>& relative_paths);
+ // Returns true if any of the paths in |relative_unix_paths| *should* have
+ // their contents verified. (Some files get transcoded during the install
+ // process, so we don't want to verify their contents because they are
+ // expected not to match).
+ bool ShouldVerifyAnyPaths(
+ const std::string& extension_id,
+ const base::FilePath& extension_root,
+ const std::set<base::FilePath>& relative_unix_paths);
// Set to true once we've begun shutting down.
bool shutdown_;
« no previous file with comments | « extensions/browser/content_hash_fetcher.cc ('k') | extensions/browser/content_verifier.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698